/*
 *  Copyright (c) Members of the EGEE Collaboration. 2005.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Management - Simple Fireman API
 *
 *  Authors: 
 *       Gabor Gombas <Gabor.Gombas@cern.ch>
 *       Akos Frohner <Akos.Frohner@cern.ch>
 *  Version info: $Id: seindex-simple.h,v 1.4 2005/04/25 13:25:21 dalion Exp $
 *  Release: $Name: glite-data-catalog-cli_R_1_7_2_6 $
 */

#ifndef GLITE_DATA_CATALOG_SEINDEX_SIMPLE_H
#define GLITE_DATA_CATALOG_SEINDEX_SIMPLE_H

#ifdef __cplusplus
extern "C" {
#endif

#include <stdarg.h>

#include <glite/data/catalog/c/catalog-simple.h>

/**
 * \defgroup catalog_service org.glite.data.catalog.service.ServiceBase
 * @{
 */

/**
 * Get the version of the remote endpoint.
 *
 * The returned string must be freed by the caller.
 *
 * @param ctx The general catalog context.
 *
 * @return The version string. In case of an error NULL is returned.
 */
char *glite_seindex_getVersion(glite_catalog_ctx *ctx);

/**
 * Get the schema version of the remote endpoint.
 *
 * The returned string must be freed by the caller.
 *
 * @param ctx The general catalog context.
 *
 * @return The version string. In case of an error NULL is returned.
 */
char *glite_seindex_getSchemaVersion(glite_catalog_ctx *ctx);

/**
 * Get the interface version of the remote endpoint.
 *
 * The returned string must be freed by the caller.
 *
 * @param ctx The general catalog context.
 *
 * @return The version string. In case of an error NULL is returned.
 */
char *glite_seindex_getInterfaceVersion(glite_catalog_ctx *ctx);

/* Get the service metadata for a given key. The key must not be NULL.
 *
 * The returned string must be freed by the caller.
 *
 * @param ctx The general catalog context.
 *
 * @return The metadata string. In case of an error NULL is returned.
 */
char *glite_seindex_getServiceMetadata(glite_catalog_ctx *ctx, const char *key);

/**********************************************************************
 * Function prototypes - org.glite.data.catalog.service.storageindex.SEIndex
 */

/**
 *  List all SEs where the LFN has a replica. 
 *
 * @param ctx The general catalog-context.
 * @param lfn The Logical FileName of which we search the replicas.  
 * @param resultCount Number of items in the return array.
 *
 * @return An array of strings containing the names of the SEs.
 */
char **glite_seindex_listSEbyLFN(glite_catalog_ctx *ctx, const char *lfn, int *resultCount);

/**
 * List all SEs where the GUID has a replica.
 *
 * @param ctx The general catalog-context.
 * @param guid The GUID of which we search the replicas. 
 * @param resultCount Number of items in the return array.
 *
 * @return An array of strings containing the names of the SEs.
 */
char **glite_seindex_listSEbyGUID(glite_catalog_ctx *ctx, const char *guid, int *resultCount);

/**
 * @}
 */

#ifdef __cplusplus
}
#endif

#endif /* GLITE_DATA_CATALOG_SEINDEX_SIMPLE_H */
